****** Change working directory
cd "..."


********************************************************************************
*** 							OPEN EPISODES FILE (created in step 1)
********************************************************************************
use Episodes_file_31_May_2016_10_31_35, clear


********************************************************************************
*** 				PREPARING THE DATASET FOR SURVIVAL ANALYSIS
********************************************************************************

*** Generate death event
gen death = (DeathIndicator==1)


stset date2, failure(death) time0(date1) id(Id_I) origin(time date1)
/*Subjects remain at risk after failure. These are errors. Some individuals have 
spells after death 
*/
drop if _t==.


********************************************************************************
****						PERIOD EFFECTS
********************************************************************************
stset date2, failure(death) id(Id_I) time0(date1) origin(time mdy(1,1,1813)) exit(time .)

/*In this section we are generating three periods. The period 1850-1914 is the one of interested in our paper.
*/

display mdy(1,1,1813)-mdy(1,1,1813)
display mdy(1,1,1850)-mdy(1,1,1813)
display mdy(1,1,1914)-mdy(1,1,1813)

stsplit periodSplit, at(0, 13514, 36889)


gen period = "1813-1849" if periodSplit==0 & periodSplit != 36889 & periodSplit != 13514
replace period = "1850-1914" if (periodSplit==13514)   & periodSplit != 36889  & periodSplit != 0 


********************************************************************************
****			SPLIT ON YEARS AND CREATE CensusYear
********************************************************************************
set more off

stset date2, failure(death) id(Id_I) time0(date1) origin(time mdy(1,1,1813)) exit(time .)


*(The loop must be run with all the lines at the same time, from the starting 
*to the closing brackets)
gen i=1813

while i<=1914{
local j=mdy(1,1,i)-mdy(1,1,1813)
stsplit split,at(`j')
drop split
replace i=i+1
}

drop i

gen Year=year(date1)
rename CensusYear CensusYear_org
rename Year CensusYear

********************************************************************************
***							 AGE EFFECTS
********************************************************************************

/*Some checks on the data to clean possible problems with age. */
drop if BirthDate==.
gen age1 = (date1-BirthDate)/365.25
gen age2 = (date2-BirthDate)/365.25

sort Id_I age1 age2
browse Id_I date1 date2 age1 age2
sum age1 
sum age2

br Id_I date1 date2 BirthDate death if age1<0
drop if age1<0

br Id_I date1 date2 BirthDate death if age2>100
drop if age2>100
drop age1 age2


*** Stset to use age as analysis time
drop agecat
stjoin
stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

** Creating the age groups 0-1, 1-15, 15-50, 50-70
stsplit agecat,at(0 1 15 50 70)



********************************************************************************
***							 SOIL TYPE VARIABLE
********************************************************************************

/* Merge the soil type dataset containing the columns PropID CensusYear, and columns for each soil type are (see the column names below).
*/
merge m:1 PropID CensusYear using Soilcat.dta
drop if _merge==2
drop _merge

** For each row, generate the sum of all the soil types areas
gen sumsoilcat = artificial_fill + bogpeat + clayey_till + clay_till__clay_cont_15_to_25_pe + clay_till__clay_cont_25_perc_and + fanerozoic_dolerite + fenpeat + fluvial_deposit_clay_and_silt + fluvialdeposit_sand + glacial_clay + glacial_coarse_silt_fine_sand + glacial_silty_clay + glaciofluvial_deposit + glaciofluvial_deposit_sand + gravel_till + gyttja_clay + mantle_rock_saprolite + postglacial_clay + postglacial_fine_sand + postglacial_sand + postglacial_silty_clay + precambrian_bedrock + sandy_till + sandysilty_till + sedimentary_rock + silt + water + wavewashedsediment_gravel

** Calculate percentage of the soil type area coverage for each row (i.e., for each property unit and year)
replace artificial_fill = (artificial_fill/sumsoilcat)*100
replace bogpeat = (bogpeat/sumsoilcat)*100
replace clayey_till = (clayey_till/sumsoilcat)*100
replace clay_till__clay_cont_15_to_25_pe = (clay_till__clay_cont_15_to_25_pe/sumsoilcat)*100
replace clay_till__clay_cont_25_perc_and = (clay_till__clay_cont_25_perc_and/sumsoilcat)*100
replace fanerozoic_dolerite = (fanerozoic_dolerite/sumsoilcat)*100
replace fenpeat = (fenpeat/sumsoilcat)*100
replace fluvial_deposit_clay_and_silt= (fluvial_deposit_clay_and_silt/sumsoilcat)*100
replace fluvialdeposit_sand = (fluvialdeposit_sand/sumsoilcat)*100
replace glacial_clay = (glacial_clay/sumsoilcat)*100
replace glacial_coarse_silt_fine_sand = (glacial_coarse_silt_fine_sand/sumsoilcat)*100
replace glacial_silty_clay = (glacial_silty_clay/sumsoilcat)*100
replace glaciofluvial_deposit = (glaciofluvial_deposit/sumsoilcat)*100
replace glaciofluvial_deposit_sand = (glaciofluvial_deposit_sand/sumsoilcat)*100 
replace gravel_till = (gravel_till/sumsoilcat)*100
replace gyttja_clay = (gyttja_clay/sumsoilcat)*100
replace mantle_rock_saprolite = (mantle_rock_saprolite/sumsoilcat)*100
replace postglacial_clay = (postglacial_clay/sumsoilcat)*100
replace postglacial_fine_sand = (postglacial_fine_sand/sumsoilcat)*100
replace postglacial_sand = (postglacial_sand/sumsoilcat)*100
replace postglacial_silty_clay = (postglacial_silty_clay/sumsoilcat)*100
replace precambrian_bedrock = (precambrian_bedrock/sumsoilcat)*100
replace sandy_till = (sandy_till/sumsoilcat)*100
replace sandysilty_till = (sandysilty_till/sumsoilcat)*100
replace sedimentary_rock = (sedimentary_rock/sumsoilcat)*100
replace silt = (silt/sumsoilcat)*100
replace water = (water/sumsoilcat)*100
replace wavewashedsediment_gravel = (wavewashedsediment_gravel/sumsoilcat)*100


** Categorize the soil types into larger groups

*** Clayey till
gen Clayey_till = (clayey_till) if clayey_till !=.

*** Sandy soils
gen fluv_sa_gr = (gravel_till  + sandy_till  + glacial_coarse_silt_fine_sand + fluvialdeposit_sand + wavewashedsediment_gravel + postglacial_sand + glaciofluvial_deposit_sand + glaciofluvial_deposit + postglacial_fine_sand) if fluvialdeposit_sand !=.

*** Claytill/clay
gen clay = (glacial_clay + glacial_silty_clay + clay_till__clay_cont_25_perc_and  + clay_till__clay_cont_15_to_25_pe + mantle_rock_saprolite + fluvial_deposit_clay_and_silt + postglacial_silty_clay + gyttja_clay + postglacial_clay +  glacial_coarse_silt_fine_sand  + silt ) if glacial_clay !=.

*** Rock and Peat
gen rock = (precambrian_bedrock + sedimentary_rock + fanerozoic_dolerite) if precambrian_bedrock !=.
gen peat = (bogpeat + fenpeat) if bogpeat !=.

** Artificial fill (An uncommon soil type that has been created in modern times. The largest part is in Kävlinge town.)
gen fill = artificial_fill if artificial_fill !=.


/*
Create variable for high spatial % coverage of clayey till, sand soils, clay/clay-till and mixed. 
Property units with a large share of uncultivated land; i.e., rock, fill and water and considered as the unlinked (no 6). 
Such property units constitute in total 0.58% of the children’s total time at risk.
*/
gen soilcat2 = 5 if Clayey_till !=. & fill <50& (rock + fill + water) < 20
replace soilcat2 = 1 if (Clayey_till >=75 & Clayey_till !=.)& (rock + fill + water) < 20
replace soilcat2 = 3 if (clay >=50 & clay !=.)& (rock + fill + water) < 20
replace soilcat2 = 2 if Clayey_till >50 & Clayey_till<75 & Clayey_till !=. & (rock + fill + water) < 20
replace soilcat2 = 4 if (fluv_sa_gr >=50 & fluv_sa_gr !=.)& (rock + fill + water) < 20
replace soilcat2 = 6 if Clayey_till ==.

tab soilcat2 [iw=(_t-_t0)] if  (agecat ==1) & (period =="1850-1914")

** Drop those that live within Kävlinge town (less likely to be affected for soil type).
/*
drop if PropID == "EM_Kevlinge_02"
drop if PropID == "EM_Kevlinge_03"
drop if PropID == "EM_Kevlinge_04"
drop if PropID == "EM_Kevlinge_05"
drop if PropID == "EM_Kevlinge_06"
drop if PropID == "EM_Kevlinge_07"
drop if PropID == "EM_Kevlinge_09"
drop if PropID == "EM_Kevlinge_11"
drop if PropID == "EM_Kevlinge_13"
drop if PropID == "EM_Kevlinge_14"
drop if PropID == "EM_Kevlinge_15"
drop if PropID == "EM_Kevlinge_16"
drop if PropID == "EM_Kevlinge_17"
drop if PropID == "EM_Kevlinge_18"
drop if PropID == "EM_Kevlinge_22"
drop if PropID == "EM_Kevlinge_24"
drop if fill > 50 & fill !=.

drop if PropID == "EM_Kevlinge_01"
drop if PropID == "LSM_Kevlinge_03"
drop if PropID == "LSM_Kevlinge_05"
drop if PropID == "LSM_Kevlinge_07"
drop if PropID == "LSM_Kevlinge_08"
drop if PropID == "LSM_Kevlinge_12"
drop if PropID == "LSM_Kevlinge_14"
drop if PropID == "LSM_Kevlinge_15"
drop if PropID == "LSM_Kevlinge_17"
drop if PropID == "LSM_Kevlinge_18"
drop if PropID == "LSM_Kevlinge_19"
drop if PropID == "LSM_Kevlinge_20"
drop if PropID == "LSM_Kevlinge_21"
drop if PropID == "LSM_Kevlinge_23"

drop if PropID == "EM1b"
drop if PropID == "EM01a"
drop if PropID == "LSM196"
drop if PropID == "LSM197"
drop if PropID == "LSM143"
drop if PropID == "LSM142"
drop if PropID == "LSM198"
drop if PropID == "LSM140"
drop if PropID == "LSM138"
drop if PropID == "LSM137"
drop if PropID == "LSM131"
drop if PropID == "LSM144"
drop if PropID == "LSM194"
drop if PropID == "LSM193"
drop if PropID == "LSM199"
drop if PropID == "LSM195"
*/




********************************************************************************
***							 AREA VARIABLE
********************************************************************************

* Merge dataset with area for each property unit
merge m:1 PropID using PropID_Area.dta
drop if _merge==2
drop _merge

* Reclassify to hectare
gen Area2 = Area * 100
* Reclassify to Are
gen Area3 = Area * 10000



********************************************************************************
***		ALTERNATIVE OCCUPATIONS (Not used in this paper)
********************************************************************************

** Import occupation codings
import delimited "Occupation_hiscode_hisclass_socpo.txt", case(preserve) clear

forvalues n = 1(1)3{ 
rename Socpo`n' SP`n'
} 

forvalues n = 1(1)3{ 
rename Hisclass`n' HC`n'
} 

drop if Code_2==.

keep Code_2 HC* SP*

save StandardOccupations.dta, replace

use Episodes_file_31_May_2016_10_31_35, clear
*** Standardize occupations

foreach occ of varlist CensusOcc1 CensusOcc2 CensusOcc3 FamHeadOccEvents FamHeadOccIncome IndivOcc IndivOcc_Income {
gen Code_2 = `occ'
merge m:1 Code_2 using StandardOccupations.dta
drop if _merge==2
drop _merge Code_2

foreach std of varlist HC* SP*{
rename `std' `occ'_`std'
}

drop `occ'
}

forvalues occ = 1(1)6  {
gen Code_2 = BirthFatherOccCode2_`occ'
merge m:1 Code_2 using StandardOccupations.dta
drop if _merge==2
drop _merge Code_2

foreach std of varlist HC* SP*{
rename `std' BirthOcc`occ'_`std'
}

drop BirthFatherOccCode2_`occ'
}

*FAMILY OCCUPATION
foreach occvar of varlist  CensusOcc1_HC* CensusOcc2_HC* CensusOcc3_HC*{ 
replace `occvar'=-1 if `occvar'==.
replace `occvar' = 99 if `occvar'<0
}

foreach occvar of varlist  FamHeadOccEvents_HC* FamHeadOccIncome_HC*{ 
replace `occvar'=-1 if `occvar'==.
replace `occvar' = 99 if `occvar'<0
}

gen famocc_cens_hciscl=min(CensusOcc1_HC1, CensusOcc1_HC2, CensusOcc1_HC3, CensusOcc2_HC1, CensusOcc2_HC2, CensusOcc2_HC3, CensusOcc3_HC1, CensusOcc3_HC2, CensusOcc3_HC3)
drop CensusOcc1_HC1 CensusOcc1_HC2 CensusOcc1_HC3 CensusOcc2_HC1 CensusOcc2_HC2 CensusOcc2_HC3 CensusOcc3_HC1 CensusOcc3_HC2 CensusOcc3_HC3
gen famocc_event_hciscl=min(FamHeadOccEvents_HC1, FamHeadOccEvents_HC2, FamHeadOccEvents_HC3)  
drop FamHeadOccEvents_HC1 FamHeadOccEvents_HC2 FamHeadOccEvents_HC3
gen famocc_income_hciscl=min(FamHeadOccIncome_HC1, FamHeadOccIncome_HC2, FamHeadOccIncome_HC3)
drop FamHeadOccIncome_HC1 FamHeadOccIncome_HC2 FamHeadOccIncome_HC3
gen hisclass_fam=min(famocc_cens_hciscl, famocc_event_hciscl, famocc_income_hciscl)
drop famocc_cens_hciscl famocc_event_hciscl famocc_income_hciscl


*INDIVIDUAL OCCUPATION
foreach occvar of varlist  IndivOcc_HC*  IndivOcc_Income_HC*{ 
replace `occvar'=-1 if `occvar'==.
replace `occvar' = 99 if `occvar'<0
}

gen indocc_event_hciscl=min(IndivOcc_HC1, IndivOcc_HC2, IndivOcc_HC3)
drop IndivOcc_HC*
gen indocc_income_hciscl=min(IndivOcc_Income_HC1, IndivOcc_Income_HC2, IndivOcc_Income_HC3)
drop IndivOcc_Income_HC*
gen hisclass_ind=min(indocc_event_hciscl, indocc_income_hciscl)
drop indocc_event_hciscl indocc_income_hciscl

*ses groups
*1: Higher occs
*2: Skilled workers
*3: Farmers
*4: Lower skilled
*5: Unskilled
*6: NA

gen ses=0
replace ses=6 if hisclass_fam == 99
replace ses=5 if hisclass_fam == 11 
replace ses=5 if hisclass_fam == 12
replace ses=4 if hisclass_fam == 9 
replace ses=4 if hisclass_fam == 10 
replace ses=3 if hisclass_fam == 8 
replace ses=3 if SizeFraction > 0
replace ses=2 if hisclass_fam == 7
replace ses=1 if hisclass_fam < 7 

label define ses 1 "Higher occ." 2 "Skilled" 3 "Farmers" 4 "Lower skilled" 5 "Unskilled" 6 "NA"
label values ses ses

*Assigning servants and lodgers their own occupations
gen hisclass_fam_s = hisclass_fam
replace hisclass_fam_s = hisclass_ind if RecordIndivNoReal>=100

gen ses_servants=0
replace ses_servants=6 if hisclass_fam_s == 99
replace ses_servants=5 if hisclass_fam_s == 11 
replace ses_servants=5 if hisclass_fam_s == 12
replace ses_servants=4 if hisclass_fam_s == 9 
replace ses_servants=4 if hisclass_fam_s == 10 
replace ses_servants=3 if hisclass_fam_s == 8 
replace ses_servants=3 if SizeFraction > 0
replace ses_servants=2 if hisclass_fam_s == 7
replace ses_servants=1 if hisclass_fam_s < 7 


** Using SOCPO
foreach occvar of varlist CensusOcc1_SP* CensusOcc2_SP* CensusOcc3_SP*{ 
replace `occvar' = 0 if `occvar'<0 | `occvar'==999 | `occvar'==.
}

foreach occvar of varlist FamHeadOccEvents_SP* FamHeadOccIncome_SP* { 
replace `occvar' = 0 if `occvar'<0 | `occvar'==999 | `occvar'==.
}

foreach occvar of varlist  IndivOcc_SP* IndivOcc_Income_SP*{ 
replace `occvar' = 0 if `occvar'<0 | `occvar'==999 | `occvar'==.
}


gen famocc_cens_sp=max(CensusOcc1_SP1, CensusOcc1_SP2, CensusOcc1_SP3, CensusOcc2_SP1, CensusOcc2_SP2, CensusOcc2_SP3, CensusOcc3_SP1, CensusOcc3_SP2, CensusOcc3_SP3)
drop CensusOcc1_SP1 CensusOcc1_SP2 CensusOcc1_SP3 CensusOcc2_SP1 CensusOcc2_SP2 CensusOcc2_SP3 CensusOcc3_SP1 CensusOcc3_SP2 CensusOcc3_SP3

gen famocc_event_sp=max(FamHeadOccEvents_SP1, FamHeadOccEvents_SP2, FamHeadOccEvents_SP3)
drop  FamHeadOccEvents_SP1 FamHeadOccEvents_SP2 FamHeadOccEvents_SP3
gen famocc_income_sp=max(FamHeadOccIncome_SP1, FamHeadOccIncome_SP2, FamHeadOccIncome_SP3)
drop FamHeadOccIncome_SP1 FamHeadOccIncome_SP2 FamHeadOccIncome_SP3

gen sp_fam=max(famocc_cens_sp, famocc_event_sp, famocc_income_sp)
drop famocc_cens_sp famocc_event_sp famocc_income_sp

gen indocc_event_sp=max(IndivOcc_SP1, IndivOcc_SP2, IndivOcc_SP3)
drop IndivOcc_SP1 IndivOcc_SP2 IndivOcc_SP3
gen indocc_income_sp=max(IndivOcc_Income_SP1, IndivOcc_Income_SP2, IndivOcc_Income_SP3)
drop IndivOcc_Income_SP1 IndivOcc_Income_SP2 IndivOcc_Income_SP3

gen sp_ind=max(indocc_event_sp, indocc_income_sp)
drop indocc_event_sp indocc_income_sp



gen sp_fam_servants = sp_fam
replace sp_fam_servants = sp_ind if RecordIndivNoReal>=100 

**Birth occupation
forvalues n = 1(1)6{
foreach occvar of varlist  BirthOcc`n'_SP*{ 
replace `occvar' = 0 if `occvar'<0 | `occvar'==999 | `occvar'==.
}
}



gen BirthOcc_sp=max(BirthOcc1_SP1, BirthOcc1_SP2, BirthOcc1_SP3, BirthOcc2_SP1, BirthOcc2_SP2, BirthOcc2_SP3, BirthOcc3_SP1, BirthOcc3_SP2, BirthOcc3_SP3, BirthOcc4_SP1, BirthOcc4_SP2, BirthOcc4_SP3, BirthOcc5_SP1, BirthOcc5_SP2, BirthOcc5_SP3, BirthOcc6_SP1, BirthOcc6_SP2, BirthOcc6_SP3) 


forvalues n = 1(1)6{
foreach occvar of varlist  BirthOcc`n'_SP*{ 
drop `occvar' 
}
}




********************************************************************************
***							 	SES AND SES v2
********************************************************************************

** SES: Freeholders, Tenants, Semi-landless and landless

**Exclude the higest occupations and the persons owning large property units (which are most likely not affected by soiltype).
*drop if SizeFraction > 3 | hisclass_fam == 1
/*
All servants are classified according to their sizefraction value. Servant children who belong to the same family of the household head will be 
assigned the corresponding sizefraction
1 = Freeholders
2 = Tenants
3 =Semilandless
4 = Landless

landses 5 can be dropped because a SizeFraction of -2 indicate an error.
*/

gen landses = 5 if SizeFraction == -2
replace landses= 1 if SizeFraction>=0.03125 & SizeFraction!=. & SizeFraction!=-1 & SizeFraction!=-2 & (LandTypeID!=5)
replace landses= 2 if SizeFraction>=0.03125 & SizeFraction!=. & SizeFraction!=-1 & SizeFraction!=-2 & (LandTypeID==5)
replace landses= 4 if (SizeFraction==-1| SizeFraction==0 | SizeFraction==.) &  SizeFraction !=-2
replace landses= 3 if TypeOfHolding==4|TypeOfHolding==5|(SizeFraction<0.03125 & SizeFraction!=0 & SizeFraction!=-1 & SizeFraction != -2)

** SES v2
/*
1 = Small- and medium-scaled farmers
2 = Labourers
3 = Large-scale farmers

*if landses 5 is not dropped, consider to drop observations with SizeFraction -2
*/
gen farmlab = 1 if (SizeFraction < 0.4 & SizeFraction > 0.015 & Area2 < 100 & Area2 >= 2 & (period =="1850-1914"))|(SizeFraction <= 0.03125& SizeFraction > 0.015 & Area2 > 100 & (period =="1850-1914") )|(SizeFraction <0.4& SizeFraction > 0.015 & Area2 < 2 & (period =="1850-1914") )
replace farmlab = 2 if ((landses==4)|(SizeFraction <= 0.015|(Area2 < 2 & SizeFraction < 0.03125)))& (period =="1850-1914")
replace farmlab = 3 if  (period =="1850-1914") & (SizeFraction >= 0.4 | ((landses==1|landses==2)&(Area2 >=100)))



********************************************************************************
***		CREATE VARIABLES FOR DEATH CAUSE (Used in the cause-specific models
********************************************************************************

replace death = 0 if death==.

gen StandardCause = CauseOfDeath_std1
replace StandardCause = CauseOfDeath_std2 if StandardCause==4 & (CauseOfDeath_std2==1 | CauseOfDeath_std2==7)
replace StandardCause = CauseOfDeath_std3 if StandardCause==4 & (CauseOfDeath_std3==1 | CauseOfDeath_std3==7)
replace StandardCause=. if death!=1
replace StandardCause = 9 if death==1 & StandardCause==0 | StandardCause==99
replace StandardCause=9 if StandardCause==.

label define stdCause 1 "Airborne" 2 "FoodBorne" 3 "OtherInfectious" 4 "CardiovascularDiabetes" 5 "Accidents" 6 "OldAgeWeakness" 7 "Cancer" 8 "OtherNonInfect" 9 "NotSpecified"
label values StandardCause stdCause

/*
deathCompt = 1: Airborne infectious diseases
deathCompt = 2: Non-airborne infectious diseases/not specified
*/
replace deathCompt = 0 if death==0
replace deathCompt = 1 if (death==1 & StandardCause==1)
replace deathCompt = 2 if (death==1 & StandardCause!=1)



********************************************************************************
***			VARIABLES FOR SENSITVITIY TESTS (Appendix 1 in the paper)
********************************************************************************

** Dummy for landless and semilandless residing in Satellite units/Demesnes - 
gen MansionL =3 if Area2 ==.
replace MansionL =1 if Area2 !=.
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (PropID=="Loarp_1_4"|PropID =="Knutstorp_05"|PropID =="Dufeke_seteri"|PropID =="Boketofta"|PropID =="Knutstorp_seteri"|PropID =="Dufeke_01"|PropID =="Simmelsberga"|PropID =="Bensige"|PropID =="Simmelsberga_1_6"|PropID =="Sirekopinge_Seteri"|PropID =="Sirekopinge_16"|PropID =="Mollarp_seteri"|PropID =="Dufeke"|PropID =="Mollarp_seteri"|PropID =="Bullstofta_02"|PropID =="Halmstad_1910_6"|PropID =="849"|PropID =="Halmstad_1848_0"|PropID =="1910_137"|PropID =="1849_58"|PropID =="839"|PropID =="859"|PropID =="7"|PropID =="Halmstad_1801_581"|PropID =="Halmstad_1910_69"|PropID =="867"|PropID =="99776"|PropID =="63")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="Tagarp_101910_169"|PropID=="1849_61"|PropID=="1910_114"|PropID=="1849_46"|PropID=="1849_47"|PropID=="1849_49"|PropID=="1849_48"|PropID=="1910_117"|PropID=="1910_116")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="Tagarp_08"|PropID=="1910_165"|PropID=="1849_70"|PropID=="Tagarp_07"|PropID=="1849_69"|PropID=="1910_164"|PropID=="Tagarp_03"|PropID=="1849_65"|PropID=="1910_159"|PropID=="1910_158"|PropID=="1910_155"|PropID=="1910_156"|PropID=="1910_157"|PropID=="Tagarp_01"|PropID=="1849_60"|PropID=="1910_145"|PropID=="Tagarp_02"|PropID=="1849_64")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="1910_154"|PropID=="1910_149"|PropID=="1910_146"|PropID=="1849_63"|PropID=="1849_62"|PropID=="Hakantorp_01"|PropID=="Hakantorp_02"|PropID=="1910_29"|PropID=="1849_7"|PropID=="1757_86"|PropID=="1804_84"|PropID=="Klesinge_01"|PropID=="Klesinge_02")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="1850_8"|PropID=="1850_11"|PropID=="1850_10"|PropID=="1850_12"|PropID=="1850_9"|PropID=="1850_13"|PropID=="1910_35"|PropID=="1910_36"|PropID=="1910_33"|PropID=="1910_32"|PropID=="1910_31"|PropID=="1910_34"|PropID=="1910_39"|PropID=="1910_37"|PropID=="1850_15"|PropID=="1850_14"|PropID=="1850_16"|PropID=="Klesinge_03")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="Klesinge_04"|PropID=="Klesinge_05"|PropID=="Klesinge_06"|PropID=="1850_17"|PropID=="1910_40"|PropID=="1910_42"|PropID=="1910_41"|PropID=="1850_18"|PropID=="1849_19"|PropID=="1910_43"|PropID=="1910_44"|PropID=="1849_20"|PropID=="1910_78"|PropID=="Norraby_05"|PropID=="1849_33"|PropID=="1849_34"|PropID=="Norraby_06")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="1910_79"|PropID=="1910_192"|PropID=="Norraby_09"|PropID=="1849_36"|PropID=="1849_27"|PropID=="Norraby_10"|PropID=="1910_191"|PropID=="1910_98"|PropID=="Norrlycke_01"|PropID=="1849_37"|PropID=="Sirekopinge_01"|PropID=="Sirekopinge_02"|PropID=="Sirekopinge_03"|PropID=="Sirekopinge_04"|PropID=="Sirekopinge_05"|PropID=="Sirekopinge_06")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="Sirekopinge_07"|PropID=="Sirekopinge_09"|PropID=="1910_108"|PropID=="1910_106"|PropID=="1910_107"|PropID=="1910_104"|PropID=="1910_103"|PropID=="1910_102"|PropID=="1910_109"|PropID=="1910_111"|PropID=="1910_110"|PropID=="1849_43"|PropID=="1849_42"|PropID=="1849_45"|PropID=="1849_44"|PropID=="1910_112"|PropID=="1910_113"|PropID=="1910_115")
replace MansionL =2 if Area2 !=. & (landses ==4|landses==3) & (MansionL==2|PropID=="1910_119"|PropID=="1910_118"|PropID=="1849_50"|PropID=="1849_51"|PropID=="1849_53"|PropID=="1849_52"|PropID=="1910_121"|PropID=="1910_120"|PropID=="1849_57"|PropID=="1849_56"|PropID=="1910_129"|PropID=="1910_128"|PropID=="1910_130"|PropID=="Spargott_01"|PropID=="1849_58"|PropID=="1849_59")
                              


** Population density measure

***Merge Population density in square km.
merge m:1 PropID CensusYear using PropID_PopDensitySQKM.dta
drop if _merge==2
drop _merge

***Categorical variable

**** Alt 1 Classify above and below median and 25th and 75th percentile (average is not appropriate to use because the distribution is long-tailed and right scewed) 
replace PopDensKM = 1 if PopDensSQKM < 73.45 & PopDensSQKM !=.
replace PopDensKM = 2 if PopDensSQKM >= 73.45 & PopDensSQKM !=.
replace PopDensKM = 3 if PopDensSQKM ==. & PopDensKM != 2 & PopDensKM !=1

**** Alt 2 (approximately equal shares of person-years)
replace PopDensKM = 1 if PopDensSQKM < 45 & PopDensSQKM !=.
replace PopDensKM = 2 if PopDensSQKM >= 45 & PopDensSQKM  < 160 & PopDensSQKM !=.
replace PopDensKM = 3 if PopDensSQKM >= 160 & PopDensSQKM !=.
replace PopDensKM = 4 if PopDensSQKM ==. & PopDensKM != 2 & PopDensKM !=1
tab PopDensKM [iw=(_t-_t0)] if (agecat==1) & (period =="1850-1914") 



********************************************************************************
***							 	SAVE FILE
********************************************************************************
save SEDD_soilType_Ep_30Apr2015_C.dta, replace




