cd "..."
use SEDD_soilType_Ep_30Apr2015_C, clear

set more off, permanently

drop if Sex=="unknown"
drop if Parish==-2 

char ParishNo [omit] 5
char landses [omit] 3
char farmlab [omit] 2
char soilcat2 [omit] 1

** centering year of birth
sum BirthYear if agecat == 1 & (period == "1850-1914")
gen cen_byr=BirthYear-1873

stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)



********************************************************************************
***		MODELS FOR TABLE 3 - ALL CHILDREN
********************************************************************************
stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

* Model 1a (Parish-SES)
xi: stpiece i.ParishNo i.landses cen_byr i.Sex if (agecat==1) & (period =="1850-1914") , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 1b – Non-airborne (Parish-SES)
stset date2, failure(deathCompt==2) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.landses cen_byr i.Sex  if (agecat==1) & (period =="1850-1914"),  compete(deathCompt == 1) 

* Model 1c - Airborne (Parish-SES)
stset date2, failure(deathCompt==1) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.landses cen_byr i.Sex if (agecat==1) & (period =="1850-1914"),  compete(deathCompt == 2) 

*(stset for all-causes mortality)
stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

* Model 2 (Parish-SES v2). 
xi: stpiece i.ParishNo i.farmlab cen_byr i.Sex if (agecat==1) & (period =="1850-1914") , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 3 (Parish - Tax). 
xi: stpiece i.ParishNo SizeFraction cen_byr i.Sex if (agecat==1) & (period =="1850-1914") , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 4 (Parish – Soil type)
xi: stpiece i.ParishNo i.soilcat2 cen_byr i.Sex if (agecat==1) & (period =="1850-1914") , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5a (Parish - SES v2 - Tax - Soil type)
xi: stpiece i.ParishNo i.soilcat2 i.farmlab SizeFraction cen_byr i.Sex if (agecat==1) & (period =="1850-1914") , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5b – Non airborne (Parish - SES v2 - Tax - Soil type)
stset date2, failure(deathCompt==2) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.soilcat2 i.farmlab SizeFraction cen_byr i.Sex  if (agecat==1) & (period =="1850-1914"),  compete(deathCompt == 1) 

* Model 5c - Airborne (Parish - SES v2 - Tax - Soil type)
stset date2, failure(deathCompt==1) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.soilcat2 i.farmlab SizeFraction cen_byr i.Sex  if (agecat==1) & (period =="1850-1914"),  compete(deathCompt == 2) 


********************************************************************************
***		MODELS FOR TABLE 4 - FARMERS
********************************************************************************

stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

*1 Model 1a (Parish-SES)
xi: stpiece i.ParishNo cen_byr i.Sex if (agecat==1) & farmlab==1 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 3 (Parish - Tax). 
xi: stpiece  i.ParishNo SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==1 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 4 (Parish – Soil type). 
xi: stpiece  i.ParishNo i.soilcat2 cen_byr i.Sex if (agecat==1) & farmlab==1 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5a (Parish - SES v2 - Tax - Soil type)
xi: stpiece  i.ParishNo i.soilcat2 SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==1 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5b – Non airborne (Parish - Tax - Soil type). 
stset date2, failure(deathCompt==2) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.soilcat2 SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==1 & (period =="1850-1914") ,  compete(deathCompt == 1) 


********************************************************************************
***		MODELS FOR TABLE 5 - LABOURERS
********************************************************************************

stset date2, failure(death) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

*1 Model 1a (Parish-SES)
xi: stpiece i.ParishNo cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 3 (Parish - Tax). 
xi: stpiece  i.ParishNo SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 4 (Parish – Soil type). 
xi: stpiece  i.ParishNo i.soilcat2 cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5a (Parish - SES v2 - Tax - Soil type)
xi: stpiece  i.ParishNo i.soilcat2 SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914")  , tp(5(0.5)15) shared(HouseholdID) forceshared

* Model 5b – Non airborne (Parish - Tax - Soil type)
stset date2, failure(deathCompt==2) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.soilcat2 SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914") ,  compete(deathCompt == 1) 

* Model 5c – Airborne (Parish - Tax - Soil type)
stset date2, failure(deathCompt==1) id(Id_I) time0(date1) origin(time BirthDate) scale(365.25)

xi: stcrreg i.ParishNo i.soilcat2 SizeFraction cen_byr i.Sex if (agecat==1) & farmlab==2 & (period =="1850-1914"),  compete(deathCompt == 2) 

